var showdown = require('showdown')
var {Parser, createRenderHTML} = require('@toast-ui/toastmark' )
module.exports = async (inputs, callback, done) => {
  try {
    let htmlContent = ''
    if(inputs.mode === 'simple') {

      const converter = new showdown.Converter({
        strikethrough: true,
        tasklists: true,
        simpleLineBreaks: true,
        parseImgDimensions: true,
        ...inputs.convertOptions
      })
      htmlContent = converter.makeHtml(inputs.markdown)

    }else if(inputs.mode === 'raw'){
      const parser = new Parser(); // This is the parser used by TOAST UI Editor

      const root = parser.parse(inputs.markdown);
      htmlContent = createRenderHTML(root);

    }else{
      let content = inputs.markdown
      if(!content)content = ""
      content = content.replace(/\r/g,"").split("\n").map( line => "'" + line.replace(/'/g,"\\'") + "\\n'").join(" + \n")

      htmlContent = `
    <link rel="stylesheet" href="https://uicdn.toast.com/editor/latest/toastui-editor-viewer.min.css" />
    <link rel="stylesheet" href="https://uicdn.toast.com/tui.chart/latest/tui-chart.min.css" />
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/9.15.10/styles/github.min.css" />
    <style>
        /*.tui-editor-contents pre{*/
            /*background-color: white;*/
        /*}*/
    </style>
    <div id="viewer"/>
    <script src="https://uicdn.toast.com/editor/latest/toastui-editor-viewer.js"></script>
    <script src="https://uicdn.toast.com/editor-plugin-chart/latest/toastui-editor-plugin-chart.min.js"></script>
    <script src="https://uicdn.toast.com/editor-plugin-code-syntax-highlight/latest/toastui-editor-plugin-code-syntax-highlight-all.min.js"></script>
    <script src="https://uicdn.toast.com/editor-plugin-table-merged-cell/latest/toastui-editor-plugin-table-merged-cell.min.js"></script>
    <script src="https://uicdn.toast.com/editor-plugin-uml/latest/toastui-editor-plugin-uml.min.js"></script>



<script>
    function whenAvailable(name, callback, interval = 10) {

        window.setTimeout(function() {
            if (window[name]) {
                callback(window[name]);
            } else {
                whenAvailable(name, callback, interval);
            }
        }, interval);
    }
    whenAvailable('toastui', () =>{
        const Viewer = toastui.Editor;
        const { chart, codeSyntaxHighlight, tableMergedCell, uml } = Viewer.plugin;
        const chartOptions = {
            minWidth: 100,
            minHeight: 100,
        };
        const viewer = new Viewer({
            el: document.querySelector('#viewer'),
            initialValue: ${content},
            plugins: [[chart, chartOptions], codeSyntaxHighlight, tableMergedCell, uml]
        });
        window.JSREPORT_READY_TO_START=true
    })
</script>

      `
    }

    done(null, {
      htmlContent
    })

  } catch (e) {
    done(null, {
      error: {
        message: e.message,
        stack: e.stack
      }
    })
  }
}


